ol.vips.enums

Generated enum descriptors for normalized libvips enum ids.

Use registry or the generated enum vars to inspect enum metadata. Use ol.vips/encode-enum and ol.vips/decode-enum to convert between keywords and the underlying libvips integer values.

Generated enum descriptors for normalized libvips enum ids.

Use [[registry]] or the generated enum vars to inspect enum metadata. Use [[ol.vips/encode-enum]] and [[ol.vips/decode-enum]] to convert between keywords and the underlying libvips integer values.
raw docstring

accessclj

Generated enum descriptor for VipsAccess.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :random
  • :sequential
  • :sequential-unbuffered
Generated enum descriptor for `VipsAccess`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:random`
- `:sequential`
- `:sequential-unbuffered`
sourceraw docstring

alignclj

Generated enum descriptor for VipsAlign.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :centre
  • :high
  • :low
Generated enum descriptor for `VipsAlign`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:centre`
- `:high`
- `:low`
sourceraw docstring

angleclj

Generated enum descriptor for VipsAngle.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :d0
  • :d180
  • :d270
  • :d90
Generated enum descriptor for `VipsAngle`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:d0`
- `:d180`
- `:d270`
- `:d90`
sourceraw docstring

angle45clj

Generated enum descriptor for VipsAngle45.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :d0
  • :d135
  • :d180
  • :d225
  • :d270
  • :d315
  • :d45
  • :d90
Generated enum descriptor for `VipsAngle45`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:d0`
- `:d135`
- `:d180`
- `:d225`
- `:d270`
- `:d315`
- `:d45`
- `:d90`
sourceraw docstring

band-formatclj

Generated enum descriptor for VipsBandFormat.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :char
  • :complex
  • :double
  • :dpcomplex
  • :float
  • :int
  • :notset
  • :short
  • :uchar
  • :uint
  • :ushort
Generated enum descriptor for `VipsBandFormat`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:char`
- `:complex`
- `:double`
- `:dpcomplex`
- `:float`
- `:int`
- `:notset`
- `:short`
- `:uchar`
- `:uint`
- `:ushort`
sourceraw docstring

blend-modeclj

Generated enum descriptor for VipsBlendMode.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :add
  • :atop
  • :clear
  • :colour-burn
  • :colour-dodge
  • :darken
  • :dest
  • :dest-atop
  • :dest-in
  • :dest-out
  • :dest-over
  • :difference
  • :exclusion
  • :hard-light
  • :in
  • :lighten
  • :multiply
  • :out
  • :over
  • :overlay
  • :saturate
  • :screen
  • :soft-light
  • :source
  • :xor
Generated enum descriptor for `VipsBlendMode`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:add`
- `:atop`
- `:clear`
- `:colour-burn`
- `:colour-dodge`
- `:darken`
- `:dest`
- `:dest-atop`
- `:dest-in`
- `:dest-out`
- `:dest-over`
- `:difference`
- `:exclusion`
- `:hard-light`
- `:in`
- `:lighten`
- `:multiply`
- `:out`
- `:over`
- `:overlay`
- `:saturate`
- `:screen`
- `:soft-light`
- `:source`
- `:xor`
sourceraw docstring

codingclj

Generated enum descriptor for VipsCoding.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :error
  • :labq
  • :none
  • :rad
Generated enum descriptor for `VipsCoding`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:error`
- `:labq`
- `:none`
- `:rad`
sourceraw docstring

combineclj

Generated enum descriptor for VipsCombine.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :max
  • :min
  • :sum
Generated enum descriptor for `VipsCombine`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:max`
- `:min`
- `:sum`
sourceraw docstring

combine-modeclj

Generated enum descriptor for VipsCombineMode.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :add
  • :set
Generated enum descriptor for `VipsCombineMode`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:add`
- `:set`
sourceraw docstring

compass-directionclj

Generated enum descriptor for VipsCompassDirection.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :centre
  • :east
  • :north
  • :north-east
  • :north-west
  • :south
  • :south-east
  • :south-west
  • :west
Generated enum descriptor for `VipsCompassDirection`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:centre`
- `:east`
- `:north`
- `:north-east`
- `:north-west`
- `:south`
- `:south-east`
- `:south-west`
- `:west`
sourceraw docstring

directionclj

Generated enum descriptor for VipsDirection.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :horizontal
  • :vertical
Generated enum descriptor for `VipsDirection`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:horizontal`
- `:vertical`
sourceraw docstring

enumsclj

(enums)

Lists the generated libvips enum ids.

Lists the generated libvips enum ids.
sourceraw docstring

extendclj

Generated enum descriptor for VipsExtend.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :background
  • :black
  • :copy
  • :mirror
  • :repeat
  • :white
Generated enum descriptor for `VipsExtend`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:background`
- `:black`
- `:copy`
- `:mirror`
- `:repeat`
- `:white`
sourceraw docstring

fail-onclj

Generated enum descriptor for VipsFailOn.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :error
  • :none
  • :truncated
  • :warning
Generated enum descriptor for `VipsFailOn`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:error`
- `:none`
- `:truncated`
- `:warning`
sourceraw docstring

foreign-dz-containerclj

Generated enum descriptor for VipsForeignDzContainer.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :fs
  • :szi
  • :zip
Generated enum descriptor for `VipsForeignDzContainer`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:fs`
- `:szi`
- `:zip`
sourceraw docstring

foreign-dz-depthclj

Generated enum descriptor for VipsForeignDzDepth.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :one
  • :onepixel
  • :onetile
Generated enum descriptor for `VipsForeignDzDepth`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:one`
- `:onepixel`
- `:onetile`
sourceraw docstring

foreign-dz-layoutclj

Generated enum descriptor for VipsForeignDzLayout.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :dz
  • :google
  • :iiif
  • :iiif3
  • :zoomify
Generated enum descriptor for `VipsForeignDzLayout`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:dz`
- `:google`
- `:iiif`
- `:iiif3`
- `:zoomify`
sourceraw docstring

foreign-heif-compressionclj

Generated enum descriptor for VipsForeignHeifCompression.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :av1
  • :avc
  • :hevc
  • :jpeg
Generated enum descriptor for `VipsForeignHeifCompression`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:av1`
- `:avc`
- `:hevc`
- `:jpeg`
sourceraw docstring

foreign-heif-encoderclj

Generated enum descriptor for VipsForeignHeifEncoder.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :aom
  • :auto
  • :rav1e
  • :svt
  • :x265
Generated enum descriptor for `VipsForeignHeifEncoder`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:aom`
- `:auto`
- `:rav1e`
- `:svt`
- `:x265`
sourceraw docstring

foreign-subsampleclj

Generated enum descriptor for VipsForeignSubsample.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :auto
  • :off
  • :on
Generated enum descriptor for `VipsForeignSubsample`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:auto`
- `:off`
- `:on`
sourceraw docstring

foreign-tiff-compressionclj

Generated enum descriptor for VipsForeignTiffCompression.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :ccittfax4
  • :deflate
  • :jp2k
  • :jpeg
  • :lzw
  • :none
  • :packbits
  • :webp
  • :zstd
Generated enum descriptor for `VipsForeignTiffCompression`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:ccittfax4`
- `:deflate`
- `:jp2k`
- `:jpeg`
- `:lzw`
- `:none`
- `:packbits`
- `:webp`
- `:zstd`
sourceraw docstring

foreign-tiff-predictorclj

Generated enum descriptor for VipsForeignTiffPredictor.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :float
  • :horizontal
  • :none
Generated enum descriptor for `VipsForeignTiffPredictor`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:float`
- `:horizontal`
- `:none`
sourceraw docstring

foreign-tiff-resunitclj

Generated enum descriptor for VipsForeignTiffResunit.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :cm
  • :inch
Generated enum descriptor for `VipsForeignTiffResunit`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:cm`
- `:inch`
sourceraw docstring

foreign-webp-presetclj

Generated enum descriptor for VipsForeignWebpPreset.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :default
  • :drawing
  • :icon
  • :photo
  • :picture
  • :text
Generated enum descriptor for `VipsForeignWebpPreset`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:default`
- `:drawing`
- `:icon`
- `:photo`
- `:picture`
- `:text`
sourceraw docstring

intentclj

Generated enum descriptor for VipsIntent.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :absolute
  • :auto
  • :perceptual
  • :relative
  • :saturation
Generated enum descriptor for `VipsIntent`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:absolute`
- `:auto`
- `:perceptual`
- `:relative`
- `:saturation`
sourceraw docstring

interestingclj

Generated enum descriptor for VipsInteresting.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :all
  • :attention
  • :centre
  • :entropy
  • :high
  • :low
  • :none
Generated enum descriptor for `VipsInteresting`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:all`
- `:attention`
- `:centre`
- `:entropy`
- `:high`
- `:low`
- `:none`
sourceraw docstring

interpretationclj

Generated enum descriptor for VipsInterpretation.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :b-w
  • :cmc
  • :cmyk
  • :error
  • :fourier
  • :grey16
  • :histogram
  • :hsv
  • :lab
  • :labq
  • :labs
  • :lch
  • :matrix
  • :multiband
  • :oklab
  • :oklch
  • :rgb
  • :rgb16
  • :scrgb
  • :srgb
  • :xyz
  • :yxy
Generated enum descriptor for `VipsInterpretation`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:b-w`
- `:cmc`
- `:cmyk`
- `:error`
- `:fourier`
- `:grey16`
- `:histogram`
- `:hsv`
- `:lab`
- `:labq`
- `:labs`
- `:lch`
- `:matrix`
- `:multiband`
- `:oklab`
- `:oklch`
- `:rgb`
- `:rgb16`
- `:scrgb`
- `:srgb`
- `:xyz`
- `:yxy`
sourceraw docstring

kernelclj

Generated enum descriptor for VipsKernel.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :cubic
  • :lanczos2
  • :lanczos3
  • :linear
  • :mitchell
  • :mks2013
  • :mks2021
  • :nearest
Generated enum descriptor for `VipsKernel`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:cubic`
- `:lanczos2`
- `:lanczos3`
- `:linear`
- `:mitchell`
- `:mks2013`
- `:mks2021`
- `:nearest`
sourceraw docstring

operation-booleanclj

Generated enum descriptor for VipsOperationBoolean.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :and
  • :eor
  • :lshift
  • :or
  • :rshift
Generated enum descriptor for `VipsOperationBoolean`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:and`
- `:eor`
- `:lshift`
- `:or`
- `:rshift`
sourceraw docstring

operation-complexclj

Generated enum descriptor for VipsOperationComplex.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :conj
  • :polar
  • :rect
Generated enum descriptor for `VipsOperationComplex`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:conj`
- `:polar`
- `:rect`
sourceraw docstring

operation-complex2clj

Generated enum descriptor for VipsOperationComplex2.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :cross-phase
Generated enum descriptor for `VipsOperationComplex2`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:cross-phase`
sourceraw docstring

operation-complexgetclj

Generated enum descriptor for VipsOperationComplexget.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :imag
  • :real
Generated enum descriptor for `VipsOperationComplexget`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:imag`
- `:real`
sourceraw docstring

operation-mathclj

Generated enum descriptor for VipsOperationMath.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :acos
  • :acosh
  • :asin
  • :asinh
  • :atan
  • :atanh
  • :cos
  • :cosh
  • :exp
  • :exp10
  • :log
  • :log10
  • :sin
  • :sinh
  • :tan
  • :tanh
Generated enum descriptor for `VipsOperationMath`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:acos`
- `:acosh`
- `:asin`
- `:asinh`
- `:atan`
- `:atanh`
- `:cos`
- `:cosh`
- `:exp`
- `:exp10`
- `:log`
- `:log10`
- `:sin`
- `:sinh`
- `:tan`
- `:tanh`
sourceraw docstring

operation-math2clj

Generated enum descriptor for VipsOperationMath2.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :atan2
  • :pow
  • :wop
Generated enum descriptor for `VipsOperationMath2`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:atan2`
- `:pow`
- `:wop`
sourceraw docstring

operation-morphologyclj

Generated enum descriptor for VipsOperationMorphology.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :dilate
  • :erode
Generated enum descriptor for `VipsOperationMorphology`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:dilate`
- `:erode`
sourceraw docstring

operation-relationalclj

Generated enum descriptor for VipsOperationRelational.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :equal
  • :less
  • :lesseq
  • :more
  • :moreeq
  • :noteq
Generated enum descriptor for `VipsOperationRelational`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:equal`
- `:less`
- `:lesseq`
- `:more`
- `:moreeq`
- `:noteq`
sourceraw docstring

operation-roundclj

Generated enum descriptor for VipsOperationRound.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :ceil
  • :floor
  • :rint
Generated enum descriptor for `VipsOperationRound`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:ceil`
- `:floor`
- `:rint`
sourceraw docstring

pcsclj

Generated enum descriptor for VipsPCS.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :lab
  • :xyz
Generated enum descriptor for `VipsPCS`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:lab`
- `:xyz`
sourceraw docstring

precisionclj

Generated enum descriptor for VipsPrecision.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :approximate
  • :float
  • :integer
Generated enum descriptor for `VipsPrecision`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:approximate`
- `:float`
- `:integer`
sourceraw docstring

region-shrinkclj

Generated enum descriptor for VipsRegionShrink.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :max
  • :mean
  • :median
  • :min
  • :mode
  • :nearest
Generated enum descriptor for `VipsRegionShrink`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:max`
- `:mean`
- `:median`
- `:min`
- `:mode`
- `:nearest`
sourceraw docstring

registryclj

Generated registry of libvips enum descriptors keyed by normalized enum id.

Generated registry of libvips enum descriptors keyed by normalized enum id.
sourceraw docstring

sdf-shapeclj

Generated enum descriptor for VipsSdfShape.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :box
  • :circle
  • :line
  • :rounded-box
Generated enum descriptor for `VipsSdfShape`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:box`
- `:circle`
- `:line`
- `:rounded-box`
sourceraw docstring

sizeclj

Generated enum descriptor for VipsSize.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :both
  • :down
  • :force
  • :up
Generated enum descriptor for `VipsSize`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:both`
- `:down`
- `:force`
- `:up`
sourceraw docstring

text-wrapclj

Generated enum descriptor for VipsTextWrap.

Use this value directly or look it up in registry when you want the generated enum map.

Known values:

  • :char
  • :none
  • :word
  • :word-char
Generated enum descriptor for `VipsTextWrap`.

Use this value directly or look it up in [[registry]] when you want the generated enum map.

Known values:
- `:char`
- `:none`
- `:word`
- `:word-char`
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries