Generated enum descriptors for normalized libvips enum ids.
Use registry or the generated enum vars to inspect enum metadata. Use ol.vips/encode-enum and ol.vips/decode-enum to convert between keywords and the underlying libvips integer values.
Generated enum descriptors for normalized libvips enum ids. Use [[registry]] or the generated enum vars to inspect enum metadata. Use [[ol.vips/encode-enum]] and [[ol.vips/decode-enum]] to convert between keywords and the underlying libvips integer values.
Generated enum descriptor for VipsAccess.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:random:sequential:sequential-unbufferedGenerated enum descriptor for `VipsAccess`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:random` - `:sequential` - `:sequential-unbuffered`
Generated enum descriptor for VipsAlign.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:centre:high:lowGenerated enum descriptor for `VipsAlign`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:centre` - `:high` - `:low`
Generated enum descriptor for VipsAngle.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:d0:d180:d270:d90Generated enum descriptor for `VipsAngle`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:d0` - `:d180` - `:d270` - `:d90`
Generated enum descriptor for VipsAngle45.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:d0:d135:d180:d225:d270:d315:d45:d90Generated enum descriptor for `VipsAngle45`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:d0` - `:d135` - `:d180` - `:d225` - `:d270` - `:d315` - `:d45` - `:d90`
Generated enum descriptor for VipsBandFormat.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:char:complex:double:dpcomplex:float:int:notset:short:uchar:uint:ushortGenerated enum descriptor for `VipsBandFormat`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:char` - `:complex` - `:double` - `:dpcomplex` - `:float` - `:int` - `:notset` - `:short` - `:uchar` - `:uint` - `:ushort`
Generated enum descriptor for VipsBlendMode.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:add:atop:clear:colour-burn:colour-dodge:darken:dest:dest-atop:dest-in:dest-out:dest-over:difference:exclusion:hard-light:in:lighten:multiply:out:over:overlay:saturate:screen:soft-light:source:xorGenerated enum descriptor for `VipsBlendMode`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:add` - `:atop` - `:clear` - `:colour-burn` - `:colour-dodge` - `:darken` - `:dest` - `:dest-atop` - `:dest-in` - `:dest-out` - `:dest-over` - `:difference` - `:exclusion` - `:hard-light` - `:in` - `:lighten` - `:multiply` - `:out` - `:over` - `:overlay` - `:saturate` - `:screen` - `:soft-light` - `:source` - `:xor`
Generated enum descriptor for VipsCoding.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:error:labq:none:radGenerated enum descriptor for `VipsCoding`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:error` - `:labq` - `:none` - `:rad`
Generated enum descriptor for VipsCombine.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:max:min:sumGenerated enum descriptor for `VipsCombine`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:max` - `:min` - `:sum`
Generated enum descriptor for VipsCombineMode.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:add:setGenerated enum descriptor for `VipsCombineMode`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:add` - `:set`
Generated enum descriptor for VipsCompassDirection.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:centre:east:north:north-east:north-west:south:south-east:south-west:westGenerated enum descriptor for `VipsCompassDirection`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:centre` - `:east` - `:north` - `:north-east` - `:north-west` - `:south` - `:south-east` - `:south-west` - `:west`
Generated enum descriptor for VipsDirection.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:horizontal:verticalGenerated enum descriptor for `VipsDirection`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:horizontal` - `:vertical`
(enums)Lists the generated libvips enum ids.
Lists the generated libvips enum ids.
Generated enum descriptor for VipsExtend.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:background:black:copy:mirror:repeat:whiteGenerated enum descriptor for `VipsExtend`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:background` - `:black` - `:copy` - `:mirror` - `:repeat` - `:white`
Generated enum descriptor for VipsFailOn.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:error:none:truncated:warningGenerated enum descriptor for `VipsFailOn`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:error` - `:none` - `:truncated` - `:warning`
Generated enum descriptor for VipsForeignDzContainer.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:fs:szi:zipGenerated enum descriptor for `VipsForeignDzContainer`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:fs` - `:szi` - `:zip`
Generated enum descriptor for VipsForeignDzDepth.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:one:onepixel:onetileGenerated enum descriptor for `VipsForeignDzDepth`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:one` - `:onepixel` - `:onetile`
Generated enum descriptor for VipsForeignDzLayout.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:dz:google:iiif:iiif3:zoomifyGenerated enum descriptor for `VipsForeignDzLayout`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:dz` - `:google` - `:iiif` - `:iiif3` - `:zoomify`
Generated enum descriptor for VipsForeignHeifCompression.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:av1:avc:hevc:jpegGenerated enum descriptor for `VipsForeignHeifCompression`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:av1` - `:avc` - `:hevc` - `:jpeg`
Generated enum descriptor for VipsForeignHeifEncoder.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:aom:auto:rav1e:svt:x265Generated enum descriptor for `VipsForeignHeifEncoder`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:aom` - `:auto` - `:rav1e` - `:svt` - `:x265`
Generated enum descriptor for VipsForeignSubsample.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:auto:off:onGenerated enum descriptor for `VipsForeignSubsample`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:auto` - `:off` - `:on`
Generated enum descriptor for VipsForeignTiffCompression.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:ccittfax4:deflate:jp2k:jpeg:lzw:none:packbits:webp:zstdGenerated enum descriptor for `VipsForeignTiffCompression`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:ccittfax4` - `:deflate` - `:jp2k` - `:jpeg` - `:lzw` - `:none` - `:packbits` - `:webp` - `:zstd`
Generated enum descriptor for VipsForeignTiffPredictor.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:float:horizontal:noneGenerated enum descriptor for `VipsForeignTiffPredictor`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:float` - `:horizontal` - `:none`
Generated enum descriptor for VipsForeignTiffResunit.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:cm:inchGenerated enum descriptor for `VipsForeignTiffResunit`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:cm` - `:inch`
Generated enum descriptor for VipsForeignWebpPreset.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:default:drawing:icon:photo:picture:textGenerated enum descriptor for `VipsForeignWebpPreset`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:default` - `:drawing` - `:icon` - `:photo` - `:picture` - `:text`
Generated enum descriptor for VipsIntent.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:absolute:auto:perceptual:relative:saturationGenerated enum descriptor for `VipsIntent`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:absolute` - `:auto` - `:perceptual` - `:relative` - `:saturation`
Generated enum descriptor for VipsInteresting.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:all:attention:centre:entropy:high:low:noneGenerated enum descriptor for `VipsInteresting`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:all` - `:attention` - `:centre` - `:entropy` - `:high` - `:low` - `:none`
Generated enum descriptor for VipsInterpretation.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:b-w:cmc:cmyk:error:fourier:grey16:histogram:hsv:lab:labq:labs:lch:matrix:multiband:oklab:oklch:rgb:rgb16:scrgb:srgb:xyz:yxyGenerated enum descriptor for `VipsInterpretation`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:b-w` - `:cmc` - `:cmyk` - `:error` - `:fourier` - `:grey16` - `:histogram` - `:hsv` - `:lab` - `:labq` - `:labs` - `:lch` - `:matrix` - `:multiband` - `:oklab` - `:oklch` - `:rgb` - `:rgb16` - `:scrgb` - `:srgb` - `:xyz` - `:yxy`
Generated enum descriptor for VipsKernel.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:cubic:lanczos2:lanczos3:linear:mitchell:mks2013:mks2021:nearestGenerated enum descriptor for `VipsKernel`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:cubic` - `:lanczos2` - `:lanczos3` - `:linear` - `:mitchell` - `:mks2013` - `:mks2021` - `:nearest`
Generated enum descriptor for VipsOperationBoolean.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:and:eor:lshift:or:rshiftGenerated enum descriptor for `VipsOperationBoolean`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:and` - `:eor` - `:lshift` - `:or` - `:rshift`
Generated enum descriptor for VipsOperationComplex.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:conj:polar:rectGenerated enum descriptor for `VipsOperationComplex`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:conj` - `:polar` - `:rect`
Generated enum descriptor for VipsOperationComplex2.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:cross-phaseGenerated enum descriptor for `VipsOperationComplex2`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:cross-phase`
Generated enum descriptor for VipsOperationComplexget.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:imag:realGenerated enum descriptor for `VipsOperationComplexget`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:imag` - `:real`
Generated enum descriptor for VipsOperationMath.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:acos:acosh:asin:asinh:atan:atanh:cos:cosh:exp:exp10:log:log10:sin:sinh:tan:tanhGenerated enum descriptor for `VipsOperationMath`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:acos` - `:acosh` - `:asin` - `:asinh` - `:atan` - `:atanh` - `:cos` - `:cosh` - `:exp` - `:exp10` - `:log` - `:log10` - `:sin` - `:sinh` - `:tan` - `:tanh`
Generated enum descriptor for VipsOperationMath2.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:atan2:pow:wopGenerated enum descriptor for `VipsOperationMath2`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:atan2` - `:pow` - `:wop`
Generated enum descriptor for VipsOperationMorphology.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:dilate:erodeGenerated enum descriptor for `VipsOperationMorphology`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:dilate` - `:erode`
Generated enum descriptor for VipsOperationRelational.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:equal:less:lesseq:more:moreeq:noteqGenerated enum descriptor for `VipsOperationRelational`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:equal` - `:less` - `:lesseq` - `:more` - `:moreeq` - `:noteq`
Generated enum descriptor for VipsOperationRound.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:ceil:floor:rintGenerated enum descriptor for `VipsOperationRound`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:ceil` - `:floor` - `:rint`
Generated enum descriptor for VipsPCS.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:lab:xyzGenerated enum descriptor for `VipsPCS`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:lab` - `:xyz`
Generated enum descriptor for VipsPrecision.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:approximate:float:integerGenerated enum descriptor for `VipsPrecision`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:approximate` - `:float` - `:integer`
Generated enum descriptor for VipsRegionShrink.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:max:mean:median:min:mode:nearestGenerated enum descriptor for `VipsRegionShrink`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:max` - `:mean` - `:median` - `:min` - `:mode` - `:nearest`
Generated registry of libvips enum descriptors keyed by normalized enum id.
Generated registry of libvips enum descriptors keyed by normalized enum id.
Generated enum descriptor for VipsSdfShape.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:box:circle:line:rounded-boxGenerated enum descriptor for `VipsSdfShape`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:box` - `:circle` - `:line` - `:rounded-box`
Generated enum descriptor for VipsSize.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:both:down:force:upGenerated enum descriptor for `VipsSize`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:both` - `:down` - `:force` - `:up`
Generated enum descriptor for VipsTextWrap.
Use this value directly or look it up in registry when you want the generated enum map.
Known values:
:char:none:word:word-charGenerated enum descriptor for `VipsTextWrap`. Use this value directly or look it up in [[registry]] when you want the generated enum map. Known values: - `:char` - `:none` - `:word` - `:word-char`
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |